#![no_std]
#![no_main]

use ble::gatt::Server;
use defmt_rtt as _;
use embassy_nrf as _;
use nrf_softdevice::Softdevice;
use panic_probe as _;

use defmt::{info, unwrap};
use embassy_executor::Spawner;

pub mod ble {
    pub mod advertisment;
    pub mod battery_service;
    pub mod gatt;
    pub mod softdevice;
}

const DEVICE_NAME: &str = "alert-me display";

#[embassy_executor::task]
async fn ble(spawner: Spawner) {
    let (sd, server) = ble::softdevice::run(spawner, DEVICE_NAME);

    loop {
        let conn = ble::advertisment::run(sd, DEVICE_NAME).await;
        let error = ble::gatt::run(&conn, &server).await;
        info!("gatt_server run exited with error: {:?}", error);
    }
}

#[embassy_executor::main]
async fn main(spawner: Spawner) {
    unwrap!(spawner.spawn(ble(spawner)));
}
